Readme
======

A library of helpers for PyTorch.

Michaël Gharbi <mgharbi@adobe.com>


Installation
------------

From pip:
``pip install torch-tools``

From source:
``python setup.py install``


Documentation
=============

The documentation webpage can be found `here https://torch-tools.readthedocs.io/en/latest/`


Demo
----

For a simple demo, look at the MNIST example in `examples/train_mnist.py`:

``python examples/train_mnist.py data out``


Contributors
------------

Dima Smirnov implemented the tensorboard hooks and callbacks.
